@@ -4,3 +4,5 @@ from .table import Table
 from .submit import Submit
 from .facets import Facets
 from .flag import Flag
+from .geopulse import Geopulse
+from .geocode import Geocode
